<?php
/**
 * Hook Helper.
 *
 * @author ThemeOO
 * @category HelperFunctions\HookHelper
 * @package ThemeOO\Core
 */

if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	die();
}

if ( ! function_exists( 'themeoo_body_classes' ) ) {
	/**
	 * Body classes.
	 *
	 * @param string[] $classes body class list.
	 *
	 * @return array
	 */
	function themeoo_body_classes( $classes ) {

		// Apply single page/post layout.
		$site_layout = themeoo_get_post_layout_options( 'site_layout' );
		if ( 'default' === $site_layout ) {
			$site_layout = themeoo_get_mod( 'layout_global_site' );
		}

		// Adds `singular` to singular pages, and `hfeed` to all other pages.
		$classes[] = is_singular() ? 'singular' : 'hfeed';
		$classes[] = 'theme-ayyash';
		$classes[] = 'boxed' === $site_layout ? 'boxed' : 'wide';

		// Adds a class of group-blog to blog with more than 1 published author.
		if ( is_multi_author() ) {
			$classes[] = 'group-blog';
		}

		return $classes;
	}
}

if ( ! function_exists( 'themeoo_post_classes' ) ) {
	/**
	 * Post class.
	 *
	 * @param string[] $classes post class list.
	 *
	 * @return array
	 */
	function themeoo_post_classes( $classes ) {
		if ( ! is_singular() ) {
			$classes[] = 'post-' . themeoo_get_content_layout( themeoo_get_current_screen() );
		} else {
			if ( 'post' === get_post_type() ) {
				$classes[] = 'post-normal post-single';
			}
		}

		return $classes;
	}
}

/**
 * Themeoo Allow tags
 *
 * @param array $allowed_tags
 *
 * @return array
 */
function themeoo_allow_tags( $allowed_tags ) {
	$allowed_tags['noscript'] = [];

	return $allowed_tags;
}

if ( ! function_exists( 'themeoo_custom_excerpt_length' ) ) {
	/**
	 * Override the_excerpt.
	 *
	 * @param int $length length.
	 *
	 * @return int
	 */
	function themeoo_custom_excerpt_length( $length ) {
		$excerpt_length = absint( themeoo_get_mod( 'layout_blog_excerpt_length' ) );
		if ( $excerpt_length ) {
			return $excerpt_length;
		}

		return $length;
	}
}

if ( ! function_exists( 'themeoo_category_transient_flusher' ) ) {
	/**
	 * Flush out the transients used in themeoo_categorized_blog.
	 *
	 * @return void
	 */
	function themeoo_category_transient_flusher() {
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		// Like, beat it. Dig?
		delete_transient( 'themeoo_category_count' );
	}
}

if ( ! function_exists( 'themeoo_skip_links' ) ) {
	/**
	 * Function Name        : themeoo_skip_links
	 * Function Hooked      : themeoo_header_skip_links
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_skip_links() {
		?>
		<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'ayyash' ); ?></a>
		<?php
	}
}

// secondary_head for top bar.
if ( ! function_exists( 'themeoo_secondary_head' ) ) {
	/**
	 * Function Name        : themeoo_action_secondary_head
	 * Function Hooked      : themeoo_header_secondary_header
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_secondary_head() {
		$header_container_cls = apply_filters( 'themeoo_header_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );
		if ( themeoo_get_mod( 'layout_header_secondary' ) ) {
			?>
			<header id="secondary-head" class="secondary-header" role="banner">
				<div class="<?php echo esc_attr( $header_container_cls ); ?>">
					<div class="row align-items-center">
						<?php themeoo_second_header(); ?>
					</div>
				</div>
			</header>
			<?php
		}
	}
}

// master head for main menu.
if ( ! function_exists( 'themeoo_master_head' ) ) {
	/**
	 * Function Name        : themeoo_action_master_head
	 * Function Hooked      : themeoo_header_master_header
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_master_head() {
		$header_container_cls = apply_filters( 'themeoo_header_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );
		?>
		<header id="masthead" class="main-header <?php echo esc_attr( themeoo_get_mod( 'layout_header_transparency_positioning' ) ? 'transparent-header ' : '' ); ?> " role="banner">
			<div class="<?php echo esc_attr( $header_container_cls ); ?>">
				<div class="masthead-wrap clearfix">
					<?php themeoo_site_branding(); ?>
					<?php themeoo_site_menu(); ?>
					<?php themeoo_header_button(); ?>
					<?php themeoo_mobile_icon(); ?>
				</div>
			</div>
		</header>
		<?php
	}
}

// Mobile Menu.

if ( ! function_exists( 'themeoo_mobile_menu' ) ) {
	/**
	 * Function Name        : themeoo_mobile_menu
	 * Function Hooked      : themeoo_mobile_menu
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_mobile_menu() {

		$mobile_menu_container_cls = apply_filters( 'themeoo_mobile_menu_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );

		$mobile_menu_view = themeoo_get_mod( 'layout_header_menu_mobileshow' );

		switch ( $mobile_menu_view ) {
			case 'sm':
				$mobile_menu_view = ' d-block d-md-none';
				break;
			case 'lg':
				$mobile_menu_view = ' d-block d-xl-none';
				break;
			case 'xl':
				$mobile_menu_view = ' d-block';
				break;
			case 'md':
			default:
				$mobile_menu_view = ' d-block d-lg-none';
				break;
		}
		$uid = wp_unique_id( 'search-' );
		?>
		<div id="navigation-mobile">
			<div class="<?php echo esc_attr( $mobile_menu_container_cls ) . esc_attr( $mobile_menu_view ); ?>">
				<div class="row">
					<div class="col-md-12">
						<?php themeoo_get_mobile_menu(); ?>
						<!-- site-mobile-menu -->
						<?php
						if ( themeoo_get_mod( 'layout_header_search' ) ) {
							?>
							<form id="mobile-search" action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get">
								<label for="<?php echo esc_attr( $uid ); ?>" class="sr-only"><?php esc_html_e( 'Search', 'ayyash' ); ?></label>
								<input type="text" name="s" id="<?php echo esc_attr( $uid ); ?>" placeholder="<?php esc_attr_e( 'Search', 'ayyash' ); ?>">
								<button type="submit">
									<i class="ti-search" aria-hidden="true"></i>
									<span class="sr-only"><?php esc_html_e( 'Search', 'ayyash' ); ?></span>
								</button>
							</form>
						<?php } ?>

						<?php if ( themeoo_get_mod( 'layout_header_button' ) ) { ?>
							<div class="themeoo-header-button">
								<a href="<?php echo esc_url( themeoo_get_mod('layout_header_button_url')); ?>">
									<?php echo wp_kses_post( themeoo_get_mod( 'layout_header_button_text' ) ); ?>
								</a>
							</div><!-- end .themeoo-header-menu-wrap -->
						<?php } ?>
					</div>
				</div>
			</div>
		</div><!-- /navigation-mobile -->
		<?php
	}
}

// Comment

if ( ! function_exists( 'themeoo_commentfields_rowtag' ) ) {
	/**
	 * Adds the Proper opening markup for comment filed.
	 *
	 * @return void
	 */
	function themeoo_commentfields_rowtag() {
		echo '<div class="row">';
	}
}

if ( ! function_exists( 'themeoo_commentfields_rowtag_end' ) ) {
	/**
	 * Adds the Proper closing markup for comment filed.
	 *
	 * @return void
	 */
	function themeoo_commentfields_rowtag_end() {
		echo '</div>';
	}
}

/**
 * Themeoo Comment Reply link
 *
 * @param string $link
 *
 * @return string
 */
function themeoo_cancel_comment_reply_link( $link ) {
	$tip = '<a data-bs-toggle="tooltip" data-bs-placement="bottom" title="' . esc_attr__( 'Cancel reply', 'ayyash' ) . '" ';

	return str_replace( '<a ', $tip, $link );
}

/**
----------------------------------------------------------------------
 * Page Option related Function
 *----------------------------------------------------------------------*/

// Secondary Header Enable Disable.

if ( ! function_exists( 'themeoo_single_secondary_header' ) ) {
	/**
	 * Function Name        : themeoo_single_secondary_header
	 * Description          : Remove secondary header for single page or post
	 * Function Hooked      : themeoo_single_option
	 * Function return Type : markup for secondary head or remove action
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_single_secondary_header() {
		$secondary_header = themeoo_get_post_layout_options( 'secondary_header' );
		if ( 'default' !== $secondary_header ) {
			if ( 'enable' === $secondary_header ) {
				add_action( 'themeoo_header_secondary_header', 'themeoo_secondary_head' );
			} else {
				remove_action( 'themeoo_header_secondary_header', 'themeoo_secondary_head' );
			}
		}
	}
}
// Master header Enable Disable.
if ( ! function_exists( 'themeoo_single_master_header' ) ) {
	/**
	 * Function Name        : themeoo_single_master_header
	 * Description          : Enable / Disable master head for single page
	 * Function Hooked      : themeoo_single_option
	 * Function return Type : html header markup
	 * Parameter            : post or page id
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_single_master_header() {
		$header_option = themeoo_get_post_layout_options( 'display_header' );
		if ( 'disable' === $header_option ) {
			remove_action( 'themeoo_header_master_header', 'themeoo_master_head' );
		}

	}
}

/**
 * Themeoo Grid Layout Loop Start
 *
 * @param string $themeoo_layout
 *
 * @return void
 */
function themeoo_grid_loop_layout_start( $themeoo_layout ) {
	if ( 'grid' == $themeoo_layout ) {
		?><div class="post-grid-wrap"><?php
	}
}

/**
 * Themeoo Grid Layout Loop End
 *
 * @param string $themeoo_layout
 *
 * @return void
 */
function themeoo_grid_loop_layout_end( $themeoo_layout ) {
	if ( 'grid' == $themeoo_layout ) {
		?></div><!-- .post-grid-wrap --><?php
	}
}

if ( ! function_exists( 'themeoo_render_footer_top' ) ) {

	/**
	 * Function Name        : themeoo_render_footer_top
	 * Function Hooked      : themeoo_footer_top_widget
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_render_footer_top() {
		$footer_top_container_cls = apply_filters( 'themeoo_footer_top_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );
		if ( ! is_active_sidebar( 'footer-top-widget' ) ) {
			return;
		}
		?>
		<div class="themeoo-footer-widget footer-top">
			<div class="<?php echo esc_attr( $footer_top_container_cls ); ?>" >
				<div class="row">
					<?php dynamic_sidebar( 'footer-top-widget' ); ?>
				</div>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'themeoo_render_footer_main' ) ) {
	/**
	 * Function Name        : themeoo_render_footer_main
	 * Function Hooked      : themeoo_footer_bottom_widget
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_render_footer_main() {
		$footer_main_container_cls = apply_filters( 'themeoo_footer_main_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );
		if ( ! is_active_sidebar( 'footer-widget' ) ) {
			return;
		}
		?>
		<div class="themeoo-footer-widget footer-main">
			<div class="<?php echo esc_attr( $footer_main_container_cls ); ?>">
				<div class="row">
						<?php dynamic_sidebar( 'footer-widget' ); ?>
				</div>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'themeoo_render_footer_bottom' ) ) {

	/**
	 * Function Name        : themeoo_render_footer_top
	 * Function Hooked      : themeoo_footer_top_widget
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_render_footer_bottom() {
		$footer_bottom_container_cls = apply_filters( 'themeoo_bottom_main_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );
		if ( ! is_active_sidebar( 'footer-bottom-widget' ) ) {
			return;
		}
		?>
		<div class="themeoo-footer-widget footer-bottom">
			<div class="<?php echo esc_attr( $footer_bottom_container_cls ); ?>">
				<div class="row">
					<?php dynamic_sidebar( 'footer-bottom-widget' ); ?>
				</div>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'themeoo_render_footer_credits' ) ) {

	/**
	 * Function Name        : themeoo_render_footer_top
	 * Function Hooked      : themeoo_footer_top_widget
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_render_footer_credits() {
		?>
		<div class="themeoo-row themeoo-footer-copyright copyright">
			<div class="container-fluid">
				<div class="row">
				<div class="col-md-12">
					<div class="footer-credit">
						<div class="copyright text-center"><?php echo wp_kses_post( themeoo_get_mod( 'layout_footer_footer_text' ) ); ?></div><!-- .copyright -->
						<div class="powered-by">
						<?php
							printf(
								/* translators: %s: WordPress. */
								esc_html__( 'Proudly powered by %s.', 'ayyash' ),
								'<a href="' . esc_url( __( 'https://wordpress.org/', 'ayyash' ) ) . '" rel="noopener" target="_blank">WordPress</a>'
							);
						?>
							</div><!-- .powered-by -->
						<div class="made-with">
						<?php
							printf(
								/* translators: %s: WordPress. */
								esc_html__( 'Made with ❤️ &nbsp; by %s', 'ayyash' ),
								'<a href="' . esc_url( __( 'https://themeoo.com/', 'ayyash' ) ) . '" rel="noopener" target="_blank">ThemeOO</a>'
							);
						?>
							</div><!-- .made-with -->
					</div>
				</div>
			</div>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'themeoo_render_footer_social_icons' ) ) {
	/**
	 * Function Name        : themeoo_master_footer
	 * Function Hooked      : themeoo_footer_master_footer
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_render_footer_social_icons() {
		$footer_social_container_cls = apply_filters( 'themeoo_footer_social_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );
		if ( ! themeoo_has_social_icons() ) {
			return;
		}
		?>
		<div class="themeoo-row themeoo-footer-social-icon text-center">
			<div class="<?php echo esc_attr( $footer_social_container_cls ); ?>">
				<div class="row">
					<div class="col-md-12 themeoo-footer-social-share pt-30 mb-10">
						<ul class="list-inline list-unstyled">
							<?php themeoo_footer_social_icons(); ?>
						</ul>
					</div>
				</div>
				<!-- end row -->
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'themeoo_render_go_to_top' ) ) {
	/**
	 * Function Name        : themeoo_go_to_top
	 * Function Hooked      : themeoo_footer_go_to_top
	 * Function return Type : html
	 * Function Since       : 1.0.0
	 *
	 * @return void
	 */
	function themeoo_render_go_to_top() {
		?>
		<a href="#" class="cd-top"><i class="ti-angle-up"></i><span class="sr-only"><?php esc_html_e( 'Goto Top', 'ayyash' ); ?></span></a>
		<?php
	}
}

/**
 * Disable WP MediaElement JS in frontend (shortcodes)
 *
 * @return string
 */
function themeoo_disable_mediaelement() {
	// returning anything other then mediaelement do the job.
	return 'plyr'; // use plyr
}

/**
 * Filter thumbnail size for gallery images (archive page)
 *
 * @param array $atts
 *
 * @return array
 */
function themeoo_set_gallery_thumb_size( $atts ) {
	if ( ! is_admin() && ! is_singular() ) {

		$themeoo_layout = themeoo_get_content_layout();
		if ( 'normal' === $themeoo_layout ) {
			$atts['size'] = 'post-thumbnails';
		} else {
			$atts['size'] = 'themeoo-gallery';
		}
	}
	return $atts;
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 *
 * @since Twenty Twenty-One 1.0
 *
 * @return void
 */
function themeoo_pingback_header() {
	if ( is_singular() && pings_open() ) {
		?>
		<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php
	}
}

/**
 * Remove the `no-js` class from body if JS is supported.
 *
 * @since Twenty Twenty-One 1.0
 *
 * @return void
 */
function themeoo_supports_js() {
	?>
	<script>document.documentElement.className = document.documentElement.className.replace( /\bno-js\b/, '' ) + ' js';</script>
	<?php
}

/**
 * Filters the list of attachment image attributes.
 *
 * @param string[] $attr Array of attribute values for the image markup, keyed by attribute name.
 * @see wp_get_attachment_image()
 *
 * @return string[]
 */
function themeoo_filter_attachment_image_attributes( $attr ) {

	if ( ! themeoo_maybe_lazyload_post_thumbnail() ) {
		return $attr;
	}

	// Data Src.
	$attr['data-src'] = $attr['src'];

	// Setting 1px as default placeholder gif image.
	$attr['src'] = 'data:image/gif;base64,R0lGODlhAQABAIAAAP///wAAACH5BAEAAAAALAAAAAABAAEAAAICRAEAOw==';

	/**
	 * @TODO Make a new image size themeoo_lazy_preview with soft crop.
	 *       get the src for themeoo_lazy_preview size & set as src for the img, and set some blur effect with css.
	 *       it also needs to be tested with loading="lazy" attribute.
	 */

	// Data Src Set.
	if ( isset( $attr['srcset'] ) ) {
		$attr['data-srcset'] = $attr['srcset'];
		unset( $attr['srcset'] );
	}

	// Lazy & no-js support classes.
	$attr['class'] .= ' lazy hide-if-no-js';

	// support for bootstrap image responsive class for wc loop.
	if ( ! empty( $attr['auto_size'] ) ) {
		unset( $attr['auto_size'] );
		$attr['class'] .= ' img-responsive';
	}

	return $attr;
}

/**
 *
 * Filteer the HTML img element representing an image attachment.
 *
 * @param string       $html          HTML img element or empty string on failure.
 * @param int          $attachment_id Image attachment ID.
 * @param string|int[] $size          Requested image size. Can be any registered image size name, or
 *                                    an array of width and height values in pixels (in that order).
 * @param bool         $icon          Whether the image should be treated as an icon.
 * @param string[]     $attr          Array of attribute values for the image markup, keyed by attribute name.
 *                                    See wp_get_attachment_image().
 *
 * @return string
 */
function themeoo_add_no_js_attachment_image( $html, $attachment_id, $size, $icon, $attr ) {

	if ( ! themeoo_maybe_lazyload_post_thumbnail() ) {
		return $html;
	}

	// Remove both filter cb
	remove_filter( 'wp_get_attachment_image', 'themeoo_add_no_js_attachment_image', 9999 );
	remove_filter( 'wp_get_attachment_image_attributes', 'themeoo_filter_attachment_image_attributes', 9999 );

	$html .= '<noscript>' . wp_get_attachment_image( $attachment_id, $size, $icon, $attr ) . '</noscript>';

	add_filter( 'wp_get_attachment_image_attributes', 'themeoo_filter_attachment_image_attributes', 9999 );
	add_filter( 'wp_get_attachment_image', 'themeoo_add_no_js_attachment_image', 9999, 5 );

	return $html;
}
